Learn R Programming

librarysnapshot (version 0.1.2)

library_snapshot: library_snapshot

Description

Make a local copy of the currently used packages within the session from the currently used library.

Usage

library_snapshot(path = NULL)

Arguments

path

path to which to copy packages to; if NULL

Value

Returns the paths from which packages were copied

Examples

Run this code
# NOT RUN {

library_snapshot()

library_snapshot(path = tempdir())


# }
# NOT RUN {

# }

Run the code above in your browser using DataLab