powered by
Make a local copy of the currently used packages within the session from the currently used library.
library_snapshot(path = NULL)
path to which to copy packages to; if NULL
Returns the paths from which packages were copied
# NOT RUN { library_snapshot() library_snapshot(path = tempdir()) # } # NOT RUN { # }
Run the code above in your browser using DataLab